@@ -116,90 +116,295 @@ def domain_is_false_positive(domain: bytes) -> bool:
 
     # Common variable roots
     root_fpos = {
+        b"abbrev",
         b"adodb",
+        b"agent",
+        b"algorithm",
+        b"alias",
         b"aquota",
-        b"at",
+        b"arena",
+        b"arenastring",
         b"array",
         b"arrayprototype",
+        b"ascii",
+        b"at",
+        b"attrtable",
+        b"barrier",
+        b"base64",
+        b"basetype",
+        b"basetypefactory",
         b"basic",
+        b"before",
+        b"bignum",
+        b"bind",
+        b"blake2",
         b"button",
+        b"bytestream",
         b"cgroup",
+        b"charconv",
+        b"check",
+        b"city",
+        b"clause",
+        b"clock",
+        b"colors",
+        b"column",
+        b"common",
+        b"conditions",
+        b"config",
+        b"constructor",
         b"contributing",
+        b"conversion",
+        b"convert",
+        b"cord",
+        b"core",
+        b"crash",
+        b"crc32",
+        b"crc32c",
+        b"crypto",
         b"ctrl-alt-del",
-        b"di",
+        b"curve25519",
+        b"cycleclock",
         b"data",
         b"date",
+        b"debbugger",
+        b"decimal",
         b"default",
+        b"deferred",
+        b"demangle",
+        b"descripters",
+        b"destructible",
+        b"di",
+        b"division",
+        b"double-to-string",
+        b"downcalls",
+        b"duration",
+        b"ecdh",
         b"email",
         b"emergency",
         b"enduser",
+        b"engine",
         b"error",
+        b"escape",
+        b"escaping",
         b"event",
         b"exit",
+        b"expr",
+        b"extention",
+        b"fast-dtoa",
+        b"features",
+        b"fence",
+        b"field",
+        b"file",
+        b"fixed-dtoa",
+        b"flag",
+        b"flags",
+        b"float",
+        b"float32",
+        b"float64",
+        b"fnmatch",
+        b"forkunsafe",
+        b"format",
+        b"frame",
         b"function",
         b"functionprototype",
+        b"futex",
+        b"glob",
+        b"global",
+        b"globals",
+        b"graph",
+        b"graphcycles",
         b"graphical",
+        b"grid",
         b"halt",
+        b"hash",
+        b"heapsort",
+        b"histogram",
+        b"host",
         b"httpd",
+        b"index",
+        b"info",
+        b"infostream",
         b"init",
+        b"initialize",
         b"initrd-fs",
         b"initrd-root-fs",
+        b"inline",
         b"install",
-        b"it",
+        b"int",
+        b"int16",
+        b"int32",
+        b"int64",
+        b"int128",
+        b"interceptor",
         b"ipconf",
+        b"it",
+        b"item",
+        b"keyset",
+        b"legacy",
+        b"lexing",
+        b"lhash",
+        b"lib",
+        b"line",
+        b"lnkinfo",
         b"local-fs",
         b"local-fs-pre",
+        b"location",
+        b"logging",
+        b"lossy",
         b"manager",
+        b"match",
+        b"memfd",
+        b"memutil",
         b"memory",
+        b"message",
+        b"metatrace",
         b"method",
+        b"metrics",
         b"mount",
+        b"mutex",
         b"multi-user",
         b"myapplication",
         b"nativedate",
+        b"netinfo",
         b"network",
         b"network-online",
+        b"new",
+        b"notification",
         b"nss",
         b"nss-lookup",
+        b"nullguard",
+        b"number",
+        b"numbers",
         b"obj",
         b"object",
+        b"once",
         b"org",
+        b"os",
         b"oshlnk",
+        b"ostringstream",
+        b"output",
+        b"parser",
         b"path",
         b"paths",
+        b"pattern",
+        b"pickle",
+        b"pipe",
+        b"pkey",
+        b"platform",
+        b"port",
         b"poweroff",
+        b"printable",
+        b"process",
+        b"program",
+        b"property",
+        b"proto",
+        b"prtime",
+        b"prtracer",
+        b"quicksort",
+        b"rand",
+        b"randen",
+        b"random",
+        b"reader",
         b"reboot",
+        b"refcount",
         b"remote",
         b"remote-fs",
         b"remote-fs-pre",
         b"rescue",
         b"response",
+        b"result",
         b"ribbon",
+        b"roots",
         b"rpcbind",
+        b"runtests",
+        b"rvalue",
+        b"sequence",
         b"service",
         b"set",
-        b"socket",
-        b"sockets",
-        b"string",
+        b"settings",
+        b"sha1",
+        b"sha256",
+        b"sha512",
+        b"shift",
         b"shutdown",
+        b"signal",
+        b"signalhandler",
+        b"signals",
         b"sigpwr",
         b"simple",
+        b"socket",
+        b"sockets",
+        b"spinlock",
+        b"stack",
+        b"stacktrace",
         b"startup",
+        b"state",
+        b"status",
+        b"statusor",
+        b"strcat",
+        b"strerror",
+        b"string",
+        b"string-to-double",
+        b"stringpiece",
+        b"strlcpy",
+        b"strtod",
+        b"strutil",
+        b"subprocess",
+        b"substitute",
         b"swap",
+        b"symbolize",
         b"syntaxerror",
+        b"sysinfo",
         b"sysinit",
         b"syslog",
         b"system",
         b"table",
+        b"tactic",
+        b"tagging",
+        b"tail",
+        b"task",
+        b"tasks",
+        b"technique",
+        b"test",
+        b"testdomain",
+        b"thread",
         b"time",
+        b"timer",
         b"timers",
         b"time-sync",
+        b"timezone",
+        b"token",
         b"tomcat",
+        b"tracing",
+        b"track",
+        b"trie",
         b"ui",
+        b"uint16",
+        b"uint32",
+        b"uint64",
         b"umount",
+        b"unix",
+        b"unscaledcycleclock",
+        b"unwinder",
+        b"upgrade",
+        b"urandom",
         b"user",
+        b"utf8",
+        b"util",
+        b"utils",
+        b"uuid",
+        b"value",
+        b"values",
+        b"vector",
+        b"verinfo",
+        b"version",
+        b"versioninfo",
+        b"vlog",
         b"window",
+        b"wrapping",
         b"wscript",
         b"wshshell",
+        b"zlib",
         b"zone",
     }
     # Common variable name ends
@@ -210,6 +415,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"build",
         b"call",
         b"cat",
+        b"cc",
         b"center",
         b"city",
         b"click",
@@ -247,10 +453,12 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"pl",
         b"pm",
         b"play",
+        b"properties",
         b"py",
         b"radio",
         b"read",
         b"red",
+        b"rs",
         b"run",
         b"save",
         b"search",
@@ -269,6 +477,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"target",
         b"total",
         b"top",
+        b"xxx",
         b"zone",
     }
     return bool(
@@ -277,7 +486,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         or (tld in tld_fpos and (root in root_fpos or len(root) == 1))  # variable attribute
         or domain_lower.startswith(b"this.")  # super common variable name in javascript
         or (len(split) == 3 and split[1] == b"prototype" and len(root) < 3 and len(tld) < 3)  # javascript pattern
-        or (domain_lower.startswith(b"lib") and tld == "so")  # ELF false positive
+        or (domain_lower.startswith(b"lib") and tld == b"so")  # ELF false positive
     )
 
 
