@@ -127,7 +127,8 @@ def test_DOMAIN_RE_match(domain):
         b"C:\\path\\looks.like.a.domain.com",
         b"date.today()",
         b"domain.com-",
-        b"variable.page_load" b'fi.search="',
+        b"variable.page_load",
+        b'fi.search="',
         b"variable.call(",
         b"Microsoft.Win32",
     ],
@@ -173,6 +174,16 @@ def test_DOMAIN_RE_context(data, domain):
         b"String.link",
         b"string.search",
         b"String.prototype.at",
+        b"util.cc",
+        b"libm.so",
+        b"host.name",
+        b"numbers.rs",
+        b"test.cc",
+        b"config.cc",
+        b"colors.cc",
+        b"reader.cc",
+        b"process.name",
+        b"subprocess.call",
     ],
 )
 def test_domain_is_false_positive(domain):
